@@ -875,15 +875,24 @@ class RedisUtil:
         cls.CONN.set(key, val)
 
     @classmethod
-    def lget(cls, key: str):
+    def lgetall(cls, key: str):
         """列表获取值
         """
         key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
         cls.CONN.lrange(key, 0, -1)
 
     @classmethod
-    def lset(cls, key: dict, vals: tuple):
+    def lsetall(cls, key: dict, vals: list):
         """列表设置值
         """
         key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
-        cls.CONN.lpush(key, vals)
+        for val in vals:
+            cls.CONN.lpush(key, val)
+
+    @classmethod
+    def rsetall(cls, key: dict, vals: list):
+        """列表设置值
+        """
+        key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
+        for val in vals:
+            cls.CONN.rpush(key, val)
